Overview
========

Chat protocol should:

#. Minimize saving information on Server
#. Only two person can be speak through SFChat
#. Chat can be active 1 day

.. toctree::
   :maxdepth: 4
   :titlesonly:

   
   Investigation
   Introduction/index